( cd usr/lib64 ; rm -rf thunderbird )
( cd usr/lib64 ; ln -sf thunderbird-1.5.0.7 thunderbird )
( cd usr/bin ; rm -rf thunderbird )
( cd usr/bin ; ln -sf /usr/lib64/thunderbird-1.5.0.7/thunderbird thunderbird )
